package	jp.co.sds_corp.ratemixer.fx;

import java.io.Serializable;

import jp.co.sds_corp.fxutil.Ccy;
import jp.co.sds_corp.fxutil.CcyPair;
import jp.co.sds_corp.fxutil.MasterCache;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* 為替レートのチェック条件を保持するクラスです。
為替レートの対象とするキー情報を保持します。<BR>
基本的な使い方は、通貨ペアと期間コードを指定します。
<PRE>
&lt;target ccy1="USD" ccy2="JPY" term="SP"/&gt;
</PRE>
期間コードを省略すると、その通貨ペアの全ての期間が対象となります。
<PRE>
&lt;target ccy1="USD" ccy2="JPY"/&gt;
</PRE>
exclude属性をtrueに指定すると、指定されたキーを対象から除外します。
下の例では、EUR/JPYのSpot以外の期間が対象となります。
<PRE>
&lt;target ccy1="EUR" ccy2="JPY"/&gt;
&lt;target ccy1="EUR" ccy2="JPY" term="SP" exclude="true"/&gt;
</PRE>
*/
public class Target implements Serializable
{
	private static final long serialVersionUID = 1L;
	transient MasterCache master;
	CcyPair	pair;
	String	term;
	boolean	exclude = false;

	/**
	* オブジェクトを構築します。
	*/
	public Target() {
	}

	/**
	* 指定された条件で、オブジェクトを構築します。
	* @param	pair	通貨ペア
	* @param	term	期間
	* @param	exclude	除外フラグ
	*/
	public Target( CcyPair pair, String term, boolean exclude ) {
		this.pair = pair;
		this.term = term;
		this.exclude = exclude;
	}

	/**
	* 指定された条件で、オブジェクトを初期化します。
	* @param	config	初期化情報
	*/
	public void init( IConfiguration config ) throws Exception {
		IConfiguration atr = config.getAttributes();
		master = MasterCache.getInstance();
		String ccy1;
		String ccy2;
		ccy1 = atr.get( "ccy1" );
		ccy2 = atr.get( "ccy2" );
		term = atr.get( "term", null );
		String exc;
		exc = atr.get( "exclude", "false" );
		exclude = exc.equals( "true" );
		//pair = master.getCcyPair( ccy1, ccy2 );
		pair = new CcyPair( new Ccy( ccy1 ), new Ccy( ccy2 ) );
	}

	/**
	* この条件と一致するかを返します。
	* @return	一致する場合true、一致しない場合false
	*/
	public boolean match( FxRate rate ) {
		if ( !pair.equals( rate.getCcyPair()) ) {
			return false;
		}
		if ( term != null ) {
			if ( !term.equals( rate.getTerm()) ) {
				return false;
			}
		}
		return true;
	}

	/**
	* 通貨ペア(pair)を設定します。
	* @param	var		設定するデータ
	*/
	public void setPair( CcyPair var ) {
		this.pair = var ;
	}
	/**
	* 通貨ペア(pair)を取得します。
	* @return	pairの内容
	*/
	public CcyPair getPair() {
		return pair;
	}

	/**
	* 期間(term)を設定します。
	* @param	var		設定するデータ
	*/
	public void setTerm( String var ) {
		this.term = var ;
	}
	/**
	* 期間(term)を取得します。
	* @return	termの内容
	*/
	public String getTerm() {
		return term;
	}

	/**
	* 除外するか(exclude)を設定します。
	* @param	var		設定するデータ
	*/
	public void setExclude( boolean var ) {
		this.exclude = var ;
	}
	/**
	* 除外するか(exclude)を取得します。
	* @return	excludeの内容
	*/
	public boolean isExclude() {
		return exclude;
	}

}
